<?php
/**
 * Plugin adm_users_rights
 * 
 * @package 
 * @author Memento and jchouix
 * @copyright 2017
 * @version 1.6.2
 * @date	20/02/2017
 * @compatibility pluxml 5.5.0
 */

class adm_users_rights extends plxPlugin
{
    private $_plug_name = 'adm_users_rights';   // Nom du plugin
    
	private $_aUsers = array(); // Tableau contenant les paramètres de tous les utilisateurs
	private $_user_rights = array(); // Tableau contenant les droits de l'utilisateur identifié par la session
    
    private $_docs_rights = array(  // Tableau définissant les documents avec leurs droits associés
        'art'  => array('add' => 0, 'edit' => 0, 'act' => 0, 'del' => 0, 'allow_comm' => 0),
        'comm' => array('add' => 0, 'edit' => 0, 'act' => 0, 'del' => 0),
        'page' => array('add' => 0, 'edit' => 0, 'act' => 0, 'del' => 0),
        'cat'  => array('add' => 0, 'edit' => 0, 'act' => 0, 'del' => 0),
        'file' => array('add' => 0, 'edit' => 0, 'act' => 0, 'del' => 0, 'move' => 0, 'thumbs' => 0, 'resize' => 0),
        'dir'  => array('add' => 0, 'edit' => 0, 'act' => 0, 'del' => 0),
        'param' => array('baseconf' => 0, 'xpconf' => 0, 'viewconf' => 0, 'users' => 0, 'plugins' => 0, 'plxinfos' => 0, 'themes' => 0),      
    );      

    private $_rights_docs = array(  // Tableau définissant les droits des utilisateurs sur les documents associés
        'add'    => array('art' => 0, 'comm' => 0, 'page' => 0, 'cat' => 0, 'file' => 0, 'dir' => 0),
        'edit'   => array('art' => 0, 'comm' => 0, 'page' => 0, 'cat' => 0, 'file' => 0, 'dir' => 0),
        'act'    => array('art' => 0, 'comm' => 0, 'page' => 0, 'cat' => 0, 'file' => 0, 'dir' => 0),
        'del'    => array('art' => 0, 'comm' => 0, 'page' => 0, 'cat' => 0, 'file' => 0, 'dir' => 0),
        'move'   => array('file' => 0),
        'thumbs' => array('file' => 0),
        'resize' => array('file' => 0),
        'baseconf' => array('param' => 0),
        'xpconf' => array('param' => 0),
        'viewconf' => array('param' => 0),
        'users' => array('param' => 0),
        'plugins' => array('param' => 0),
        'plxinfos' => array('param' => 0),
        'themes' => array('param' => 0),
        'allow_comm' => array('art' => 0), // Autorisation ou non des commentaires pour l'article   
    );

	/**
	 * Constructeur de la classe
	 *
	 * @return	void
	 */
	public function __construct($default_lang)
    {              
        # Appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);
        
        # droits pour accèder à la page config.php du plugin
		$this -> setConfigProfil(PROFIL_ADMIN);

		# Ajouts des hooks
        // Déclaration des variables privées $_aUsers et $_user_rights
        $this->addHook('plxMotorConstruct', 'plxMotorConstruct');

        // Gestion des droits utilisateurs
        $this->addHook('plxAdminEditUser', 'plxAdminEditUser');
        $this->addHook('plxAdminEditUsersXml', 'plxAdminEditUsersXml');
        $this->addHook('plxAdminEditUsersUpdate', 'plxAdminEditUsersUpdate');
		$this->addHook('AdminUser', 'AdminUser');
        $this->addHook('plxMotorGetUsers', 'plxMotorGetUsers');
        
        // Articles
        $this->addHook('AdminIndexPrepend',            'AdminIndexPrepend');    
        $this->addHook('AdminArticlePrepend',          'AdminArticlePrepend');
        // Médias
        $this->addHook('AdminMediasPrepend',           'AdminMediasPrepend');
        // Catégories
        $this->addHook('AdminCategoriesPrepend',       'AdminCategoriesPrepend');
        $this->addHook('plxAdminEditCategoriesUpdate', 'plxAdminEditCategoriesUpdate');
        $this->addHook('AdminCategoryPrepend',         'AdminCategoryPrepend');                
        // Pages statiques
        $this->addHook('AdminStaticsPrepend',          'AdminStaticsPrepend');
        $this->addHook('plxAdminEditStatiquesUpdate',  'plxAdminEditStatiquesUpdate');
        $this->addHook('AdminStaticPrepend',           'AdminStaticPrepend');                
        // Commentaires
        $this->addHook('AdminCommentsPrepend',         'AdminCommentsPrepend');
        $this->addHook('AdminCommentPrepend',          'AdminCommentPrepend');                
        $this->addHook('AdminCommentNewPrepend',       'AdminCommentNewPrepend');
        // Paramètres
        $this->addHook('AdminPrepend',                 'AdminPrepend');
        $this->addHook('AdminUsersTop',                'AdminUsersTop');
        $this->addHook('AdminUserPrepend',             'AdminUserPrepend');
        $this->addHook('AdminSettingsPluginsTop',      'AdminSettingsPluginsTop');
        
        $this->addHook('AdminTopEndHead',              'AdminTopEndHead');
	}
    
    // -------------------------------------------------------------------
    
	/**
	 * Déclaration des variables privées $_aUsers et $_user_rights
	 */
    public function plxMotorConstruct()
    {
        echo "<?php
            \$this->plxPlugins->aPlugins['adm_users_rights']->set_aUsers(\$this->aUsers);
            \$this->plxPlugins->aPlugins['adm_users_rights']->set_user_rights(\$this->aUsers);            
        ?>";
    }
    
    // -------------------------------------------------------------------
    
	/**
	 * Définit la variable privée $_aUsers
     * 
     * @param array Tableau contenant les paramètres des utilisateurs
     * @return void
	 */
    public function set_aUsers($users)
    {
        $this -> _aUsers = $users;
    }
    
    // -------------------------------------------------------------------
    
	/**
	 * Définit la variable privée $_user_rights
     * 
     * @param array Tableau contenant les paramètres des utilisateurs
     * @return void
	 */
    public function set_user_rights($users)
    {
        if (isset($_SESSION['user']) && isset($users[$_SESSION['user']]['rights'])) {
            $this -> _user_rights = $users[$_SESSION['user']]['rights']; 
        }                
    }
    
    // -------------------------------------------------------------------
    
	/**
	 * Code à exécuter à l’activation du plugin
	 */
    public function OnActivate()
    {  
        $this -> OnDeactivate();
        $this -> _initRightsUsersXml();
    }
    
    // -------------------------------------------------------------------
    
	/**
	 * Code à exécuter à la désactivation du plugin
	 */
    public function OnDeactivate()
    {
        $filename = PLX_ROOT.PLX_CONFIG_PATH.'users.xml';
        
        if(!is_file($filename)) return false;
        
        $content = file_get_contents($filename);
        
        $content = preg_replace("`<rights>.*?</rights>`", '', $content);
        
        file_put_contents($filename, $content);    
    }
   
    // -------------------------------------------------------------------
    
	/**
	 * Ajoute l'enregistrement des droits par défaut des utilisateurs 
     * dans le fichier xml
     * 
     * @access private
     * @return void
	 */
    private function _initRightsUsersXml()
    {
        $filename = PLX_ROOT.PLX_CONFIG_PATH.'users.xml';

        if (!is_file($filename)) {
          return; 
        }
                
        $xml = simplexml_load_file($filename);
        
        $users = $xml -> user;
        $docs = $this -> _docs_rights;  // Déclaration des documents avec leurs droits
        
        foreach($users as $user) {
            $rights = $user -> addChild("rights", "");
                       
            foreach($docs as $doc_name => $doc_rights)
            {
                $document = $rights -> addChild($doc_name, "");
                
                foreach($doc_rights as $right_name => $right_value) {
                    $document -> addChild($right_name,  $right_value);
                }
            }
        }
        
        $xml->asXML($filename);        
    }   

    ##################################################################################
    ##################################################################################    
      
	/**
	 * Méthode qui permet de charger le script du plugin
	 */
    public function AdminTopEndHead()
    {        
        echo $this -> _getScriptUserRights();   // Script des droits de l'utilisateur
        echo $this -> _getScriptPage();         // Scripts de la page concernée
        echo $this -> _getCSStylePage();        // Feuille CSS de la page
    }
   
    // -------------------------------------------------------------------
    
    /**
     * Récupère le script des droits de l'utilisateur
     * 
     * @return string Code html du script
     */   
    private function _getScriptUserRights()
    {
        $user_rights = $this -> _user_rights;

        $docs = $this -> _docs_rights;  // Déclaration des documents avec leurs droits

        $js = '<script type="text/javascript">var plugin_adm_user_rights = {';
        
        foreach($docs as $doc_name => $doc_rights)
        {
            $js .= '"'.$doc_name.'" : {';
            
            foreach($doc_rights as $right_name => $right_value)
            {
                if ($_SESSION['user'] == '001') { // Super admin
                    $right_value = '1';   
                } else {
                    $right_value = isset($user_rights[$doc_name][$right_name])? $user_rights[$doc_name][$right_name] : $right_value;  
                }
                
                $js .= '"'.$right_name.'" : '.$right_value.',';
            }
            
            $js .= '},';
        }

        $js .= '}; </script>';
        
        return $js;
    }
   
    // -------------------------------------------------------------------
    
    /**
     * Récupère le script de la page concernée
     * 
     * @return string Code html du script
     */   
    private function _getScriptPage()
    {
        $js = '<script type="text/javascript" src="'.PLX_ROOT.'plugins/'.$this -> _plug_name.'/scripts/admin/top.js"></script>';
        
        $pages = array('index', 'article', 'medias', 'categories', 'statiques', 'comments', 'comment', 'comment_new', 'user');
        
        foreach($pages as $page) {
            if (stristr($_SERVER['SCRIPT_NAME'], $page.'.php')) {
                $js .= '<script type="text/javascript" src="'.PLX_ROOT.'plugins/'.$this -> _plug_name.'/scripts/admin/'.$page.'.js"></script>';
                
                return $js;          
            }
        }
        
        return $js;
    }
   
    // -------------------------------------------------------------------
    
    /**
     * Récupère les feuilles de style de la page
     * 
     * @return string Code html du script
     */   
    private function _getCSStylePage()
    {
        $css = '<link rel="stylesheet" type="text/css" href="'.PLX_ROOT.'plugins/'.$this -> _plug_name.'/css/user.css" media="screen" />';
       
        return $css;
    }
             
    ##################################################################################
    ##################################################################################    
    
	/**
	 * Méthode qui met à jour le fichier XML des utilisateurs
	 */
    public function plxAdminEditUsersUpdate()
    {
        /**
         * Ecriture des droits de l'utilisateur dans le fichier xml
         */
        $docs = $this -> _docs_rights;  // Déclaration des documents avec leurs droits

        foreach($docs as $doc_name => $doc_rights)
        {
            foreach($doc_rights as $right_name => $right_value)
            {
                $this -> _plxAdminEditUserRightUpdate($doc_name, $right_name, $right_value);
            }
        }
        //
    }

    // -------------------------------------------------------------------

    /**
     * Met à jour le droit d'un utilisateur dans le fichier XML des utilisateurs
     * 
     * @param string Type de document (art, comm, ...)
     * @param string droit (add, edit, del)
     * @param integer valeur par défaut du droit (0 ou 1)
     * @return string
     */
    private function _plxAdminEditUserRightUpdate($doc, $right, $default_value = 0)
    {
        echo "<?php \$this->aUsers[\$user_id]['rights']['".$doc."']['".$right."']  = isset(\$this->aUsers[\$user_id]['rights']['".$doc."']['".$right."'])?  \$this->aUsers[\$user_id]['rights']['".$doc."']['".$right."']  : ".$default_value."; ?>";
    }
       
    ##################################################################################
    ##################################################################################    
    
	/**
	 * Méthode qui édite le fichier XML des utilisateurs
	 */
    public function plxAdminEditUsersXml() 
    {
        $docs = $this -> _docs_rights;  // Déclaration des documents avec leurs droits

        $string = "<?php \$xml .= '<rights>';";
        
        foreach($docs as $doc_name => $doc_rights)
        {
            $string .= "\$xml .= '<$doc_name>';\n";
                        
            foreach($doc_rights as $right_name => $right_value)
            {
                $string .= "\$xml .= '<$right_name>'.\$user['rights']['$doc_name']['$right_name'].'</$right_name>';\n";
            }
            
            $string .= "\$xml .= '</$doc_name>';\n";
        }

        $string .= "\$xml .= '</rights>'; ?>";

        echo $string;      
    }

    ##################################################################################
    ##################################################################################    
        
	/**
	 * Méthode qui récupère le contenu des options des utilisateurs
	 */        
    public function plxMotorGetUsers() 
    {        
        $rights_docs = $this -> _rights_docs;   // Déclaration des droits associés aux documents
      
        foreach($rights_docs as $right_name => $docs)
        {
            $nb_docs = count($docs);
            $pos_doc = 0;
            
            foreach($docs as $doc_name => $right_value)
            {
                $this -> _plxMotorGetUserRight($doc_name, $right_name, $nb_docs, $pos_doc, $right_value);
                $pos_doc++;
            }
        }        
    }

    // -------------------------------------------------------------------

	/**
	 * récupère le droit d'un utilisateur
     * 
     * @param string Identifiant du document
     * @param string Identifiant du droit
     * @param integer Nombre de tag correspondant au droit présent dans le document xml
     * @param integer Position du tag correspondant au document présent dans le document xml
     * @param integer valeur par défaut du droit
     * 
     * @return void
	 */     
    private function _plxMotorGetUserRight($doc, $right, $nbTag = 1, $posDoc = 0, $default_value = 0) 
    {
         echo "<?php \$this->aUsers[\$number]['rights']['".$doc."']['".$right."'] = isset(\$iTags['".$right."'][\$i*".$nbTag."+".$posDoc."]) ?\$values[\$iTags['".$right."'][\$i*".$nbTag."+".$posDoc."]]['value'] : ".$default_value."; ?>";
    }
        
    ##################################################################################
    ##################################################################################    
    
	/**
	 * Méthode qui sauvegarde le contenu des options d'un utilisateur
	 */    
    public function plxAdminEditUser() 
    {
        $docs = $this -> _docs_rights;  // Déclaration des documents avec leurs droits
        
        foreach($docs as $doc_name => $doc_rights)
        {
            foreach($doc_rights as $right_name => $right_value)
            {
                $this -> _plxAdminEditUserRight($doc_name, $right_name);
            }
            
            $pos_doc++;
        }
    }

    // -------------------------------------------------------------------

	/**
	 * sauvegarde le droit d'un utilisateur
     * 
     * @param string Identifiant du document
     * @param string Identifiant du droit
     * 
     * @return void
	 */
    private function _plxAdminEditUserRight($doc, $right)
    {
        echo "<?php \$this->aUsers[\$content['id']]['rights']['".$doc."']['".$right."'] = empty(\$content['".$doc."_".$right."'])?  0 : 1; ?>";
    }
    
    ##################################################################################
    ##################################################################################    

    public function AdminUser() 
    {
        $this -> _display_fields_user_rights();
    }

    // -------------------------------------------------------------------

	/**
	 * Méthode qui affiche les champs de gestion des droits de l'utilisateur
     * 
     * @return void
	 */
    private function _display_fields_user_rights() 
    {
        $aUsers = $this -> _aUsers;

        $user_id = $this -> _getUserId();
        $user_profil = $aUsers[$user_id]['profil'];
        $user_rights = $aUsers[$user_id]['rights'];
             
        $string = '';
        
        if ($user_id != '001') {

            $string .= '<fieldset id="user_rights">';
            $string .= '<legend>'.ucfirst($this -> getLang('USER_RIGHTS')).'&nbsp;:</legend>';
            
            if ($user_profil == PROFIL_WRITER)
            {    
                $string .= $this -> _addArtFieldsetRights($user_rights, $user_profil);
                $string .= $this -> _addMediaFieldsetRights($user_rights);
                $string .= $this -> _addDocFieldsRightsHidden('cat',  0);
                $string .= $this -> _addDocFieldsRightsHidden('comm', 0);
                $string .= $this -> _addDocFieldsRightsHidden('page', 0);
                $string .= $this -> _addParamFieldsRightsHidden('param', 0);
            }
            elseif ($user_profil == PROFIL_EDITOR)
            {
                $string .= $this -> _addArtFieldsetRights($user_rights, $user_profil);
                $string .= $this -> _addCatFieldsetRights($user_rights);
                $string .= $this -> _addMediaFieldsetRights($user_rights);
                $string .= $this -> _addDocFieldsRightsHidden('comm', 0);
                $string .= $this -> _addDocFieldsRightsHidden('page', 0);
                $string .= $this -> _addParamFieldsRightsHidden('param', 0);
            }          
            elseif ($user_profil == PROFIL_MODERATOR) 
            {
                $string .= $this -> _addArtFieldsetRights($user_rights, $user_profil);
                $string .= $this -> _addCatFieldsetRights($user_rights);
                $string .= $this -> _addCommFieldsetRights($user_rights);
                $string .= $this -> _addMediaFieldsetRights($user_rights);                
                $string .= $this -> _addDocFieldsRightsHidden('page', 0);
                $string .= $this -> _addParamFieldsRightsHidden('param', 0);
            }          
            elseif ($user_profil == PROFIL_MANAGER)
            {
                $string .= $this -> _addArtFieldsetRights($user_rights, $user_profil);
                $string .= $this -> _addCatFieldsetRights($user_rights);
                $string .= $this -> _addCommFieldsetRights($user_rights);
                $string .= $this -> _addPageFieldsetRights($user_rights);
                $string .= $this -> _addMediaFieldsetRights($user_rights);
                $string .= $this -> _addParamFieldsRightsHidden('param', 0);
            }          
            elseif ($user_profil == PROFIL_ADMIN)
            {
                $string .= $this -> _addArtFieldsetRights($user_rights, $user_profil);
                $string .= $this -> _addCatFieldsetRights($user_rights);
                $string .= $this -> _addCommFieldsetRights($user_rights);
                $string .= $this -> _addPageFieldsetRights($user_rights);
                $string .= $this -> _addMediaFieldsetRights($user_rights);
                $string .= $this -> _addParamFieldsetRights($user_rights);
            }
            
            $string .= '</fieldset>';

        } else { // Super Administrateur
            $string .= $this -> _addDocFieldsRightsHidden('art',   1);
            $string .= $this -> _addDocFieldsRightsHidden('cat',   1);
            $string .= $this -> _addDocFieldsRightsHidden('comm',  1);
            $string .= $this -> _addDocFieldsRightsHidden('page',  1);
            $string .= $this -> _addFileFieldsRightsHidden('file', 1);
            $string .= $this -> _addDirFieldsRightsHidden('dir',   1);
            $string .= $this -> _addParamFieldsRightsHidden('param', 1);
        }
        
        echo "<?php echo '.$string.'; ?>";
    }

    // -------------------------------------------------------------------

	/**
	 * Retourne l'identifiant de l'utilisateur concerné par la gestion des droits
     * 
     * @return integer Id de l'utilisateur
	 */
    private function _getUserId()
    {
        $aUsers = $this -> _aUsers;
        
    	$user_id = plxUtils::strCheck(plxUtils::nullbyteRemove($_GET['p']));
   	
        if(!isset($aUsers[$user_id])) {
    		plxMsg::Error(L_USER_UNKNOWN);
    		header('Location: parametres_users.php');
    		exit;
    	}
        
        return $user_id;
    }

    // -------------------------------------------------------------------

    private function _addArtFieldsetRights($user_rights, $user_profil)
    {
        $doc = 'ARTICLE';
        $legend = $this -> _getFieldsetLegend($doc);
        $label_doc = $this -> getLang('A(m)').' '.$this -> getLang($doc);

        $string = '';
        $string .= '<fieldset class="user_rights">';
        $string .= '<legend>'.$legend.'</legend>';
        $string .= $this -> _AdminUser($user_rights, 'art', 'add',  sprintf(ucfirst($this -> getLang('ADD_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'art', 'edit', sprintf(ucfirst($this -> getLang('EDIT_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'art', 'act',  sprintf(ucfirst($this -> getLang('PUBLICATE_A_ITEM')), $label_doc));
        
        if ($user_profil <= PROFIL_MODERATOR) {    // Modif 5.1.4
            $string .= $this -> _AdminUser($user_rights, 'art', 'del',  sprintf(ucfirst($this -> getLang('DELETE_A_ITEM')), $label_doc));             
        } else {
            $string .= $this -> _TagHidden($doc, 'del',  0);
        }
        
        $string .= $this -> _AdminUser($user_rights, 'art', 'allow_comm', ucfirst($this -> getLang('ALLOW_OR_NOT_COMMENTS'))); // Autorisation ou non des commentaires pour l'article
        
        $string .= '</fieldset>';     
        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addDocFieldsRightsHidden($doc, $right_value = '0')
    {
        $string = '';
        
        $string .= $this -> _TagHidden($doc, 'add',  $right_value);
        $string .= $this -> _TagHidden($doc, 'edit', $right_value);
        $string .= $this -> _TagHidden($doc, 'act',  $right_value);
        $string .= $this -> _TagHidden($doc, 'del',  $right_value);
        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addCatFieldsetRights($user_rights)
    {
        $doc = 'CATEGORIE';
        $legend = $this -> _getFieldsetLegend($doc);
        $label_doc = $this -> getLang('A(f)').' '.$this -> getLang($doc);
        $label_docs = $this -> getLang('A(p)').' '.$this -> _plural($this -> getLang($doc));

        $string = '';
        $string .= '<fieldset class="user_rights">';
        $string .= '<legend>'.$legend.'</legend>';
        $string .= $this -> _AdminUser($user_rights, 'cat', 'add',  sprintf(ucfirst($this -> getLang('ADD_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'cat', 'edit', sprintf(ucfirst($this -> getLang('EDIT_OPTIONS_OF_ITEMS')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'cat', 'del',  sprintf(ucfirst($this -> getLang('DELETE_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'cat', 'act',  sprintf(ucfirst($this -> getLang('MODIFY_PARAMS_OF_ITEMS')), $label_docs));
        $string .= '</fieldset>';     

        return $string;
    }

    // -------------------------------------------------------------------

    private function _addCommFieldsetRights($user_rights)
    {
        $doc = 'COMMENT';
        $legend = $this -> _getFieldsetLegend($doc);
        $label_doc = $this -> getLang('A(m)').' '.$this -> getLang($doc);
        $label_docs = $this -> getLang('A(p)').' '.$this -> _plural($this -> getLang($doc));

        $string = '';
        $string .= '<fieldset class="user_rights">';
        $string .= '<legend>'.$legend.'</legend>';        
        $string .= $this -> _AdminUser($user_rights, 'comm', 'add',  sprintf(ucfirst($this -> getLang('ADD_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'comm', 'edit', sprintf(ucfirst($this -> getLang('EDIT_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'comm', 'del',  sprintf(ucfirst($this -> getLang('DELETE_A_ITEM')), $label_doc));          
        $string .= $this -> _AdminUser($user_rights, 'comm', 'act',  sprintf(ucfirst($this -> getLang('PUT_ON_OFFLINE_A_ITEM')), $label_docs));
        $string .= '</fieldset>';     
        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addPageFieldsetRights($user_rights)
    {
        $doc = 'PAGE_STATIC';
        $legend = $this -> _getFieldsetLegend($doc);
        $label_doc = $this -> getLang('A(f)').' '.$this -> getLang($doc);
        $label_docs = $this -> getLang('A(p)').' '.$this -> _plural($this -> getLang($doc));

        $string = '';
        $string .= '<fieldset class="user_rights">';
        $string .= '<legend>'.$legend.'</legend>';
        $string .= $this -> _AdminUser($user_rights, 'page', 'add',  sprintf(ucfirst($this -> getLang('ADD_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'page', 'edit', sprintf(ucfirst($this -> getLang('EDIT_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'page', 'del',  sprintf(ucfirst($this -> getLang('DELETE_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'page', 'act',  sprintf(ucfirst($this -> getLang('MODIFY_PARAMS_OF_ITEMS')), $label_docs));
        $string .= '</fieldset>';     
        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addParamFieldsetRights($user_rights)
    {
        $doc = 'PARAMETER';
        $legend = $this -> _getFieldsetLegend($doc);

        $string = '';
        $string .= '<fieldset class="user_rights">';
        $string .= '<legend>'.$legend.'</legend>';
        $string .= $this -> _AdminUser($user_rights, 'param', 'baseconf', sprintf(ucfirst($this -> getLang('MANAGE_A_ITEM')), $this -> getLang('THE(f)').' '.$this -> getLang('BASE_CONFIG')));
        $string .= $this -> _AdminUser($user_rights, 'param', 'xpconf',   sprintf(ucfirst($this -> getLang('MANAGE_A_ITEM')), $this -> getLang('THE(f)').' '.$this -> getLang('ADVANCED_CONFIG')));
        $string .= $this -> _AdminUser($user_rights, 'param', 'viewconf', sprintf(ucfirst($this -> getLang('MANAGE_A_ITEM')), $this -> getLang('THE(p)').' '.$this -> getLang('DISPLAY_SETTINGS')));          
        $string .= $this -> _AdminUser($user_rights, 'param', 'users',    sprintf(ucfirst($this -> getLang('MANAGE_A_ITEM')), $this -> getLang('THE(p)').' '.$this -> getLang('USERS_ACCOUNTS')));
        $string .= $this -> _AdminUser($user_rights, 'param', 'themes',   sprintf(ucfirst($this -> getLang('MANAGE_A_ITEM')), $this -> getLang('THE(p)').' '.$this -> getLang('THEMES')));
        $string .= $this -> _AdminUser($user_rights, 'param', 'plugins',  sprintf(ucfirst($this -> getLang('MANAGE_A_ITEM')), $this -> getLang('THE(p)').' '.$this -> getLang('PLUGINS')));
        $string .= $this -> _TagHidden($doc, 'plxinfos',  1);
        $string .= '</fieldset>';     
        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addParamFieldsRightsHidden($doc = 'param', $right_value = '0')
    {
        $string = '';
        
        $string .= $this -> _TagHidden($doc, 'baseconf',  $right_value);
        $string .= $this -> _TagHidden($doc, 'xpconf',    $right_value);
        $string .= $this -> _TagHidden($doc, 'viewconf',  $right_value);
        $string .= $this -> _TagHidden($doc, 'users',     $right_value);
        $string .= $this -> _TagHidden($doc, 'themes',    $right_value);
        $string .= $this -> _TagHidden($doc, 'plugins',   $right_value);
        $string .= $this -> _TagHidden($doc, 'plxinfos',  $right_value);
                        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addMediaFieldsetRights($user_rights)
    {
        $doc = 'MEDIA';
        $legend = $this -> _getFieldsetLegend($doc);

        $string = '';
        $string .= '<fieldset class="user_rights">';
        $string .= '<legend>'.$legend.'</legend>';
        $string .= $this -> _addFileFieldsRights($user_rights);
        $string .= $this -> _addDirFieldsRights($user_rights);
        $string .= '</fieldset>';     
        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addFileFieldsRights($user_rights)
    {
        $doc = 'FILE';
        $label_doc = $this -> getLang('A(m)').' '.$this -> getLang($doc);
               
        $string = '';      
        $string .= $this -> _AdminUser($user_rights, 'file', 'add',    sprintf(ucfirst($this -> getLang('ADD_A_ITEM')),    $label_doc));
//        $string .= $this -> _AdminUser($user_rights, 'file', 'edit',   sprintf(ucfirst($this -> getLang('EDIT_A_ITEM')),   $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'file', 'del',    sprintf(ucfirst($this -> getLang('DELETE_A_ITEM')), $label_doc));          
        $string .= $this -> _AdminUser($user_rights, 'file', 'move',   sprintf(ucfirst($this -> getLang('MOVE_A_ITEM')),   $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'file', 'thumbs', sprintf(ucfirst($this -> getLang('CREATE_A_ITEM')), $this -> getLang('A(p)').' '.$this -> getLang('THUMBS')));          
        $string .= $this -> _AdminUser($user_rights, 'file', 'resize', sprintf(ucfirst($this -> getLang('RESIZE_A_ITEM')), $this -> getLang('THE(p)').' '.$this -> getLang('IMAGES')));
        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addFileFieldsRightsHidden($doc = 'file', $right_value = '0')
    {
        $string ='';
        
        $string .= $this -> _TagHidden($doc, 'add',    $right_value);
//        $string .= $this -> _TagHidden($doc, 'edit', $right_value);
        $string .= $this -> _TagHidden($doc, 'del',    $right_value);
        $string .= $this -> _TagHidden($doc, 'move',   $right_value);
        $string .= $this -> _TagHidden($doc, 'thumbs', $right_value);
        $string .= $this -> _TagHidden($doc, 'resize', $right_value);
                        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addDirFieldsRights($user_rights)
    {
        $doc = 'DIRECTORY';
        $label_doc = $this -> getLang('A(m)').' '.$this -> getLang($doc);
        
        $string = '';
        $string .= $this -> _AdminUser($user_rights, 'dir', 'add',    sprintf(ucfirst($this -> getLang('ADD_A_ITEM')), $label_doc));
//        $string .= $this -> _AdminUser($user_rights, 'dir', 'edit',   sprintf(ucfirst($this -> getLang('EDIT_A_ITEM')), $label_doc));
        $string .= $this -> _AdminUser($user_rights, 'dir', 'del',    sprintf(ucfirst($this -> getLang('DELETE_A_ITEM')), $label_doc));          
        
        return $string;
    }

    // -------------------------------------------------------------------

    private function _addDirFieldsRightsHidden($doc = 'dir', $right_value = '0')
    {
        $string = '';
        
        $string .= $this -> _TagHidden($doc, 'add',  $right_value);
//        $string .= $this -> _TagHidden($doc, 'edit', $right_value);
        $string .= $this -> _TagHidden($doc, 'del',  $right_value);
                        
        return $string;
    }

    // -------------------------------------------------------------------

	/**
	 * Retourne la légende du fieldset
     * 
     * @access private
     * @param string Nom du type de document
     * @param string Présence ou non du terme Droits
     * @return string légende du fieldset
	 */
    private function _getFieldsetLegend($label_doc, $label_rights = TRUE)
    {
        $label   = empty($label_doc)? '' : $this -> _plural($this -> getLang($label_doc));       
        $label = empty($label_rights)? $label : $this -> getLang('USER_RIGHTS').' '.$label;
        
        return ucwords($label);
    }

    // -------------------------------------------------------------------

	/**
	 * Retourne un champ case à cocher définissant un droit d'utilisateur
     * 
     * @param array Tableau contenant les droits de l'utilisateur concerné
     * @param string identifiant de la section
     * @param string identifiant du droit
     * @param string Etiquette du droit
     * @return string Champ du droit
	 */    
    private function _AdminUser($user_rights, $doc, $right, $label)
    {
        $tag_id = $doc.'_'.$right;
        $checked = ! empty($user_rights[$doc][$right]) ? ' checked = "checked"' : '';
        
        return '<p>'
               .'<input id="'.$tag_id.'" name="'.$tag_id.'" type="checkbox" value="1"'.$checked.' />'
               .'<label for="'.$tag_id.'">'.$label.'</label>'
               .'</p>';
        
    }   

    // -------------------------------------------------------------------

	/**
	 * Retourne un champ input caché définissant un droit d'utilisateur
     * 
     * @param string identifiant du document
     * @param string identifiant du droit
     * @param integer Valeur par défaut du droit
     * @return string Champ du droit
	 */    
    private function _TagHidden($doc, $right, $default_value = 0)
    {
        return '<input id="'.$doc.'_'.$right.'" name="'.$doc.'_'.$right.'" type="hidden" value="'.$default_value.'" />';
    }
     
    ##################################################################################
    ##################################################################################    
    
	/**
	 * Code à exécuter à l’appel de l'index
	 */
    public function AdminIndexPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            # Aucun droit sur les articles
            if (! $user_rights['art']['add'] && ! $user_rights['art']['edit'] && ! $user_rights['art']['del'] && ! $user_rights['art']['act']) {
                header('Location: '.PLX_ROOT.'core/admin/profil.php');
            	exit;
            }
            
            # Formulaire validé
            if(!empty($_POST)) {
                
            	# Suppression d'un article
                $del_action = (isset($_POST['selection']) && $_POST['selection'] == 'delete')? 1 : 0;
            	   
            	if ($del_action && ! $user_rights['art']['del']) {	
                    $this -> _redirect_rights_error();
            	}
                //
            }
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter à l’activation des articles
	 */
    public function AdminArticlePrepend()
    {
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            if (empty($_POST)) { # Affichage du formulaire              
                // Ajout
                if (empty($_GET['a']) && ! $user_rights['art']['add']) {
                    $this -> _redirect_rights_error();                
                }
                
                //Edition
                if (! empty($_GET['a']) && ! $user_rights['art']['edit']) {
                    header('Location: '.PLX_ROOT.'core/admin/index.php');
                    exit;     
                }
            } else { # Formulaire soumis
            	
                # Suppression d'un article
            	if(isset($_POST['delete']) && ! $user_rights['art']['del']) {	
                    $this -> _redirect_rights_error();
            	}
        
            	# Mode création ou maj
                if (isset($_POST['publish'])
                    && $_POST['publish'] == L_ARTICLE_PUBLISHING_BUTTON
                    && (! $user_rights['art']['add'] || ! $user_rights['art']['act'])
                ) {                       
                        $this -> _redirect_rights_error();
                }
                
                if (isset($_POST['draft'])) {                       
                    if ($_POST['draft'] == L_ARTICLE_DRAFT_BUTTON && ! $user_rights['art']['add']) {
                        $this -> _redirect_rights_error();
                    }
                    if ($_POST['draft'] == L_ARTICLE_OFFLINE_BUTTON && ! $user_rights['art']['edit']) {
                        $this -> _redirect_rights_error();
                    }
                }
                
                if (isset($_POST['update']) && $_POST['update'] == L_ARTICLE_UPDATE_BUTTON && ! $user_rights['art']['edit']) {
                    $this -> _redirect_rights_error();  
                }                    

            	# Ajout d'une nouvelle catégorie
            	if(isset($_POST['new_category']) && ! $user_rights['cat']['add']) {
                    $this -> _redirect_rights_error();            
                }
        
            	# Previsualisation d'un article
            /*	if(isset($_POST['preview']) && ! $user_rights['art']['edit']) {
                    $this -> _redirect_rights_error();            
                }*/

            	# Choix de l'autorisation ou non des commentaires          	
                if($_POST['artId'] == '0000' && ! $user_rights['art']['allow_comm']) {
                    echo "<?php \$_POST['allow_com'] = \$plxAdmin->aConf['allow_com']; ?>";    
                }           
            }
        }
    }
         
    ##################################################################################
    ##################################################################################    
    
	/**
	 * Code à exécuter à l’activation des catégories
	 */
    public function AdminMediasPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            # Formulaire validé
            if(!empty($_POST)) {

                $del_action  = (isset($_POST['selection']) AND ((!empty($_POST['btn_ok']) AND $_POST['selection']=='delete')) AND isset($_POST['idFile'])) ? 1 : 0;            
                $move_action = (isset($_POST['selection']) AND ((!empty($_POST['btn_ok']) AND $_POST['selection']=='move')) AND isset($_POST['idFile'])) ? 1 : 0;                
                $thumbs_action = (isset($_POST['selection']) AND ((!empty($_POST['btn_ok']) AND $_POST['selection']=='thumbs')) AND isset($_POST['idFile'])) ? 1 : 0;
                
            	# Suppression d'un fichier	   
            	if ($del_action && ! $user_rights['file']['del']) {	
                    $this -> _redirect_rights_error();
            	}
        		# déplacement d'un fichier dans un autre répertoire
                elseif($move_action && !$user_rights['file']['move']) {
                    $this -> _redirect_rights_error();                
                }                
        		# création de miniature de fichier
                elseif($thumbs_action && !$user_rights['file']['thumbs']) {
                    $this -> _redirect_rights_error();                
                }
        		# ajout nouveau fichier (upload)
                elseif(!empty($_POST['btn_upload'])) {
                    if(!$user_rights['file']['add']) {
                        $this -> _redirect_rights_error();    
                    }
                    else {
                        if (!$user_rights['file']['thumbs']) {
                            echo "<?php \$_POST['thumb'] = intval(\$plxAdmin->aConf['miniatures_l']).'x'.intval(\$plxAdmin->aConf['miniatures_h']);?>";
                        }
                        
                        if (!$user_rights['file']['resize']) {
                            echo "<?php \$_POST['resize'] = intval(\$plxAdmin->aConf['images_l']).'x'.intval(\$plxAdmin->aConf['images_h']);?>";
                        }                          
                    }
                }
                
                # suppression d'un répertoire
                elseif(!empty($_POST['btn_delete']) && !empty($_POST['folder']) && $_POST['folder']!='.' && !$user_rights['dir']['del']) {
                    $this -> _redirect_rights_error();
                }
                # ajout nouveau répertoire (création)
                elseif(!empty($_POST['btn_newfolder']) && !empty($_POST['newfolder']) && !$user_rights['dir']['add']) {
                    $this -> _redirect_rights_error();
                }
            }
        }
    }
     
    ##################################################################################
    ##################################################################################    
    
	/**
	 * Code à exécuter à l’activation des catégories
	 */
    public function AdminCategoriesPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            # Aucun droit
            if (! $user_rights['cat']['add'] && ! $user_rights['cat']['edit'] && ! $user_rights['cat']['del'] && ! $user_rights['cat']['act']) {
                $this -> _redirect_rights_error();
            }
            
            # Formulaire validé
            if(!empty($_POST)) {
                
            	# Suppression d'une catégorie
                $del_action = (isset($_POST['selection']) && $_POST['selection'] == 'delete' && isset($_POST['idCategory']))? 1 : 0;
            	   
            	if ($del_action && ! $user_rights['cat']['del']) {	
                    $this -> _redirect_rights_error();
            	}
                # Ajout d'une catégorie à partir de la page article
                elseif(!empty($_POST['new_category']) && ! $user_rights['cat']['add']) {
                    $_POST['new_catname'] = '';
                }
                # Ajout d'une catégorie
                elseif(!empty($_POST['update']) && ! $user_rights['cat']['add']) {
                    array_pop($_POST['catNum']);
                }
            }
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter lors de la modification des paramètres des catégories
	 */
    public function plxAdminEditCategoriesUpdate()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            # Formulaire validé
            if(!empty($_POST)) {
                
                # mise à jour des paramètres des catégories
                if(!empty($_POST['update']) && ! $user_rights['cat']['act']) {
                   echo "<?php 
                            if (isset(\$save[\$cat_id])) { 
                                \$this->aCats[\$cat_id] = array_merge(\$this->aCats[\$cat_id], \$save[\$cat_id]);
                            }
                        ?>"; 
                }
            }
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter à l’édition d'une catégorie
	 */
    public function AdminCategoryPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
        	// Edition d'une catégorie
            if (! $user_rights['cat']['edit']) {	
                $this -> _redirect_rights_error();
        	}
        }
    }
     
    ##################################################################################
    ##################################################################################    
    
	/**
	 * Code à exécuter à l’activation des pages statiques
	 */
    public function AdminStaticsPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            # Aucun droit
            if (! $user_rights['page']['add'] && ! $user_rights['page']['edit'] && ! $user_rights['page']['del'] && ! $user_rights['page']['act']) {
                $this -> _redirect_rights_error();
            }
            
            # Formulaire validé
            if(!empty($_POST)) {
                
            	# Suppression d'une page statique
                $del_action = (isset($_POST['selection']) && $_POST['selection'] == 'delete' && isset($_POST['idStatic']))? 1 : 0;
            	   
            	if ($del_action && ! $user_rights['page']['del']) {	
                    $this -> _redirect_rights_error();
            	}
                # Ajout d'une page statique
                elseif(!empty($_POST['update']) && ! $user_rights['page']['add']) {
                    array_pop($_POST['staticNum']);
                }
            }
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter lors de la modification des paramètres des pages statiques
	 */
    public function plxAdminEditStatiquesUpdate()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            # Formulaire validé
            if(!empty($_POST)) {
                
                # mise à jour des paramètres des pages statiques
                if(!empty($_POST['update']) && ! $user_rights['page']['act']) {
                   echo "<?php 
                            if (isset(\$save[\$static_id])) { 
                                \$this->aStats[\$static_id] = array_merge(\$this->aStats[\$static_id], \$save[\$static_id]);
                            }
                        ?>"; 
                }
            }
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter à l’activation des pages statiques
	 */
    public function AdminStaticPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
        	// Edition d'une page statique
            if (! $user_rights['page']['edit']) {	
                $this -> _redirect_rights_error();
        	}
        }
    }
     
    ##################################################################################
    ##################################################################################    
    
	/**
	 * Code à exécuter à l’affichage des commentaires
	 */
    public function AdminCommentsPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            # Aucun droit
            if (! $user_rights['comm']['add'] && ! $user_rights['comm']['edit'] && ! $user_rights['comm']['del'] && ! $user_rights['comm']['act']) {
                $this -> _redirect_rights_error();
            }
            
            # Formulaire validé
            if(!empty($_POST)) {
                $del_action = (isset($_POST['selection']) AND ($_POST['selection'] == 'delete') AND isset($_POST['idCom']))? 1 : 0;
                $online_action = (isset($_POST['selection']) AND ($_POST['selection'] == 'online') AND isset($_POST['idCom']))? 1 : 0;
                $offline_action = (isset($_POST['selection']) AND ($_POST['selection'] == 'offline') AND isset($_POST['idCom']))? 1 : 0;
                
            	# Suppression d'un commentaire   
            	if ($del_action && ! $user_rights['comm']['del']) {	
                    $this -> _redirect_rights_error();
            	}
                # Mise en ligne ou hors ligne d'un commentaire
                elseif(($online_action OR $offline_action) && ! $user_rights['comm']['act']) {
                    $this -> _redirect_rights_error();
                }                
            }
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter à l’édition d'un commentaire
	 */
    public function AdminCommentPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            if (empty($_POST)) { # Affichage du formulaire                
                //Edition
                if (! empty($_GET['c']) && ! $user_rights['comm']['edit']) {
                    $this -> _redirect_rights_error(); 
                }
            } else { # Formulaire soumis
            	
                # Suppression d'un commentaire
            	if(isset($_POST['delete']) && ! $user_rights['comm']['del']) {	
                    $this -> _redirect_rights_error();
            	}

            	# Ajout d'un nouveau commentaire
            	if (isset($_POST['answer']) && ! $user_rights['comm']['add']) {
                    $this -> _redirect_rights_error();            
                }

            	# Mise en ligne ou hors ligne d'un commentaire
            	if ((isset($_POST['online']) OR isset($_POST['offline'])) && ! $user_rights['comm']['act']) {
                         $this -> _redirect_rights_error();
                }

            	# Mise à jour d'un commentaire
            	if (isset($_POST['update']) && ! $user_rights['comm']['edit']) {
                    $this -> _redirect_rights_error();            
                }
            }
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter à l’ajout d'un nouveau commentaire
	 */
    public function AdminCommentNewPrepend()
    {        
        $user_rights = $this -> _user_rights;

        if ($_SESSION['user'] != '001')
        {
            if (! $user_rights['comm']['add']) {
                $this -> _redirect_rights_error(); 
            }
       }
    }
     
    ##################################################################################
    ##################################################################################    

	/**
	 * Code à exécuter à l’affichage des options de l'utilisateur
	 */
    public function AdminUserPrepend()
    {
        if ($_SESSION['user'] != '001')
        {   
            if (!empty($_GET['p']) && ($_GET['p'] === $_SESSION['user'] OR $_GET['p'] === '001')) {
                $this -> _redirect_rights_error(); 
            }
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter à l’affichage des paramètres des utilisateurs
	 */
    public function AdminUsersTop()
    {
        if ($_SESSION['user'] != '001')
        {            
            echo "<?php
                    unset(\$plxAdmin->aUsers['001']);
                    unset(\$plxAdmin->aUsers['".$_SESSION['user']."']); 
                 ?>";
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter à l’affichage des paramètres des plugins
	 */
    public function AdminSettingsPluginsTop()
    {
        if ($_SESSION['user'] != '001')
        {            
            echo "<?php
                    unset(\$plxAdmin->plxPlugins->aPlugins['".$this -> _plug_name."']); 
                 ?>";
        }
    }

    // -------------------------------------------------------------------

	/**
	 * Code à exécuter à l’affichage des paramètres 
	 */
    public function AdminPrepend()
    {
        $user_rights = $this -> _user_rights;
        $uri = $this -> _getURI();

        if (isset($_SESSION['user']) && $_SESSION['user'] != '001')
        {            
            // Gestion de la config de base
            if (stristr($uri, 'parametres_base.php') !== FALSE && ! $user_rights['param']['baseconf']) {
                header('Location: '.PLX_ROOT.'core/admin/parametres_infos.php');
            	exit; 
            }

            // Gestion de la config avancée
            if (stristr($uri, 'parametres_avances.php') !== FALSE && ! $user_rights['param']['xpconf']) {
                $this -> _redirect_rights_error(); 
            }

            // Gestion des options d'affichage
            if ((stristr($uri, 'parametres_affichage.php') !== FALSE OR stristr($uri, 'parametres_edittpl.php') !== FALSE) && ! $user_rights['param']['viewconf']) {
                $this -> _redirect_rights_error(); 
            }

            // Gestion des utilisateurs
            if ((stristr($uri, 'parametres_users.php') !== FALSE OR stristr($uri, 'user.php') !== FALSE) && ! $user_rights['param']['users']) {
                $this -> _redirect_rights_error(); 
            } elseif (stristr($uri, 'parametres_users.php') !== FALSE && !empty($_POST)) {
                
                if (!empty($_POST['idUser'])) {
                    $key = array_search($_SESSION['user'], $_POST['idUser']);
                    unset($_POST['idUser'][$key]);                   
                }
                
                if (!empty($_POST['userNum'])) {
                    $key = array_search($_SESSION['user'], $_POST['userNum']);
                    unset($_POST['userNum'][$key]);
                }
            }
            
            // Gestion des thèmes (fichier parametres_themes.php)
            if (stristr($uri, 'parametres_themes') !== FALSE && ! $user_rights['param']['themes']) {
                $this -> _redirect_rights_error(); 
            }

            // Gestion des plugins (fichier parametres_plugins.php, parametres_plugin.php et parametres_pluginhelp.php)
            if (stristr($uri, 'parametres_plugin') !== FALSE && ! $user_rights['param']['plugins']) {
                $this -> _redirect_rights_error(); 
            }

            // Gestion des infos
            if (stristr($uri, 'parametres_infos.php') !== FALSE && ! $user_rights['param']['plxinfos']) {
                $this -> _redirect_rights_error(); 
            }
        } else {
            if (stristr($uri, 'parametres_plugins') !== FALSE && !empty($_POST['selection']) && ($_POST['selection'] == 'delete')) {              
                $this -> OnDeactivate(); 
            }
        }             
    }

    // -------------------------------------------------------------------

	/**
	 * Récupère l'uri de la page appelée 
     * 
     * @access private
     * @return string
	 */
    private function _getURI()
    {
        return $_SERVER['REQUEST_URI'];
    }
         
    ##################################################################################
    ##################################################################################    

	/**
	 * Redirige vers la page d'erreur des droits d'accès 
     * 
     * @access private
     * @return void
	 */
    private function _redirect_rights_error($error_id = 0)
    {
        header('Location: '.PLX_ROOT.'plugins/'.$this -> _plug_name.'/rights_error.php?error='.$error_id);
    	exit;     
    } 

         
    ##################################################################################
    ##################################################################################    

    // Helpers
    
	/**
	 * Retourne un mot ou un groupe de mot au pluriel 
     * 
     * @access private
     * @param string Mot à mettre au pluriel séparés par un espace
     * @param boolean Force le pluriel
     * @return string Mot au pluriel
	 */
	private function _plural($str, $force = FALSE, $delimiter = ' ')
	{
		$str = trim($str);
		
        $str_words = explode($delimiter, $str);
     
        if (count($str_words) > 1) {
             for ($i = 0; $i < count($str_words); $i++) {
                $str_words[$i] = $this -> _plural($str_words[$i]);
             }
             
             $str = implode($delimiter, $str_words);
             
        } else {
            $end = substr($str, -1);
    
    		if ($end == 'y')
    		{
    			// Y preceded by vowel => regular plural
    			$vowels = array('a', 'e', 'i', 'o', 'u');
    			$str = in_array(substr($str, -2, 1), $vowels) ? $str.'s' : substr($str, 0, -1).'ies';
    		}
    		elseif ($end == 's')
    		{
    			if ($force == TRUE)
    			{
    				$str .= 'es';
    			}
    		}
    		else
    		{
    			$str .= 's';
    		}   
        }

		return $str;
	}

} // End Class