/**
 * Plugin adm_users_rights
 * 
 * @package 
 * @author Memento and jchouix
 * @copyright 2017
 * @version 1.6.2
 * @date	20/02/2017
 * @compatibility pluxml 5.5.0
 */
 
(function () {	// initialisation

	/**
     * Cache les options de l'lment select
     *
     * @param string Id de la balise select
     * @param string Valeur de l'option  cacher de la balise select
     * @return void
     */
	function hideSelectOptions(selectId, optionValue)
	{
        var selectElement = document.getElementById(selectId);   
        var opts = selectElement.options;
        
        for (var i = 0; i < opts.length; i++) {
			var optValue = opts[i].value;

			if (optValue === optionValue) {    			 
               selectElement.removeChild(opts[i]);
			}	
		}  
        
        return true;        
	}

    // -------------------------------------------------------------------
    
	/**
     * Cache le block contenant l'lment select et le bouton OK
     *
     * @param string Id de la balise select
     * @return void
     */
	function hideSelectBlock(selectId)
	{
        var selectElement = document.getElementById(selectId);        
        var sibling = selectElement.nextSibling;
        
        while (sibling.nodeName !== "INPUT" || sibling.type != "submit") {
            sibling = sibling.nextSibling;    
        }
        
        sibling.style.display = "none";
        selectElement.style.display = "none";
                
        return true;
    }
     
    // -------------------------------------------------------------------

	/**
     * Cache les cases  cocher du tableau
     *
     * @param string Identifiant du tableau
     * @return void
     */
	function hideCheckboxesInTable(tableId)
	{
		var tableElement = document.getElementById(tableId);        
        var inputElements = tableElement.getElementsByTagName("input");

        for (var i = 0; i < inputElements.length; i++) {
            var inputElement = inputElements.item(i);
            			
            if (inputElement.type == 'checkbox') {
                inputElement.parentNode.removeChild(inputElement);
                i--;
			}	
		}  
        
        return true;        
	}
     
    // -------------------------------------------------------------------

    /**
     * Cache une ligne d'un tableau
     *
     * @param string Nom de l'attribut id de la balise table
     * @param string Nom de l'attribut class de la balise tr  cacher
     * @return void
     */
    function hideTrInTable(tableId, trClassName)
    {
		var tableElement = document.getElementById(tableId);
        var tbodyElement = tableElement.getElementsByTagName("tbody");       
        
        var trElements = tbodyElement[0].getElementsByTagName("tr");

        for (var i = 0; i < trElements.length; i++) {
            var trClass = trElements.item(i).className;

			if (trClass == trClassName) {
                trElements.item(i).style.display = 'none';
			}	
		}  
       
        return true;
    } 
     
    // -------------------------------------------------------------------
    
	/**
     * Cache l'item du menu
     *
     * @param string Nom de la class du tableau
     * @param string Valeur de l'attribut href du lien de l'item
     * @return void
     */
	function removeLinkCellsInTable(tableId, hrefValue)
	{
		var tableElement = document.getElementById(tableId);
        
        var aElements = tableElement.getElementsByTagName("a");

        for (var i = 0; i < aElements.length; i++) {
            var aHref = aElements.item(i).href;

			if (aHref.lastIndexOf(hrefValue) !== -1) {                   
               var tdElement = aElements.item(i).parentNode;
               var content = aElements.item(i).firstChild;

               tdElement.replaceChild(content, aElements.item(i));
               i--;

                //aElements.item(i).style.display = 'none';
			}	
		}  
        
        return true;
	}
     
    // -------------------------------------------------------------------
    
	/**
     * Dsactive les champs input et select prsents dans le tableau
     *
     * @param string Nom de la class du tableau
     * @return void
     */
	function desactivateFieldsInTable(tableId)
	{
		var tableElement = document.getElementById(tableId);        
        
        /**
         * Champs input
         */
        var inputElements = tableElement.getElementsByTagName("input");

        for (var i = 0; i < inputElements.length; i++) {
            var inputElement = inputElements.item(i);
            var type = inputElement.type;
            var name = inputElement.name;
            var trParentElement = inputElement.parentNode.parentNode;
            
            if (trParentElement.className != "new") {
                inputElement.readOnly = true;
            }
             
		}  
        //
            
        /**
         * Champs select
         */            
        var selectElements = tableElement.getElementsByTagName("select");

        for (var i = 0; i < selectElements.length; i++) {
            var selectElement = selectElements.item(i);                
            var trParentElement = selectElement.parentNode.parentNode;
            
            if (trParentElement.className != "new") {
                selectElement.disabled = true;
            }
		}  
        //
        
        return true;
	}
    
    // -------------------------------------------------------------------

    /**
     * Cache le bouton "Modifier la liste des pages statiques"
     *
     * @return void
     */
    function hideButtonUpdate()
    {
        var formElement = document. getElementById("form_categories");
        var inputElements = formElement.getElementsByTagName("input");
    
        for (var i = 0; i < inputElements.length; i++) {
            var type = inputElements.item(i).type;
            var name = inputElements.item(i).name;
            
            if (type == 'submit' && name == 'update') {
                inputElements.item(i).style.display = 'none';
            }       
    	}  
    }    

    // -------------------------------------------------------------------

	function init()
	{
        if (! plugin_adm_user_rights["cat"]["del"]) {
            hideSelectBlock("id_selection");
            hideCheckboxesInTable("categories-table");
        }
        
        if (! plugin_adm_user_rights["cat"]["edit"]) {
            removeLinkCellsInTable("categories-table", "categorie.php");
        }
        
        if (! plugin_adm_user_rights["cat"]["add"]) {
            hideTrInTable("categories-table", "new");
        }
        
        if (! plugin_adm_user_rights["cat"]["act"]) {
            desactivateFieldsInTable("categories-table");
        }

        if (! plugin_adm_user_rights["cat"]["add"] && ! plugin_adm_user_rights["cat"]["act"]) {
            hideButtonUpdate();
        }

	}

	/**
	 * Ajoute la fonction  l'vnement load de la page
	 */
	function addLoadListener(func)
	{
		if (window.addEventListener) {
			window.addEventListener("load", func, false);
		} else if (document.addEventListener) {
			document.addEventListener("load", func, false);
		} else if (window.attachEvent) {
			window.attachEvent("onload", func);
		}
	}

	// Chargement
	if (document.getElementsByTagName) {
		addLoadListener(init);
	}
   
})();